﻿using System.Windows;
using System.Windows.Data;
using Telerik.Windows.Controls;
using Telerik.Windows.Controls.GridView;
using System.Windows.Interactivity;
using System.Windows.Threading;
using System;
using System.Windows.Input;

namespace DoubleClickOnRow_Behavior
{
	public class DoubleClickBehavior : Behavior<RadGridView>
	{
	
		protected override void OnAttached()
		{
			base.OnAttached();

			this.AssociatedObject.RowLoaded += OnRowLoaded;
			this.AssociatedObject.RowUnloaded += OnRowUnloaded;
		}

		protected override void OnDetaching()
		{
			base.OnDetaching();

			this.AssociatedObject.RowLoaded -= OnRowLoaded;
			this.AssociatedObject.RowUnloaded -= OnRowUnloaded;
		}

		private void OnRowLoaded(object sender, RowLoadedEventArgs e)
		{
			var row = e.Row as GridViewRow;

			if (row != null)
			{
				row.AddHandler(GridViewRow.MouseLeftButtonDownEvent,new MouseButtonEventHandler(element_MouseLeftButtonDown), true);				
			}
		}

		private void OnRowUnloaded(object sender, RowUnloadedEventArgs e)
		{
			var row = e.Row as GridViewRow;

			if (row != null)
			{
				row.RemoveHandler(GridViewRow.MouseLeftButtonDownEvent, new MouseButtonEventHandler(element_MouseLeftButtonDown));	
			}
		}

	
		private DispatcherTimer doubleClickTimer;
		private int clickCount;

		
		GridViewRow row = new GridViewRow();
		void element_MouseLeftButtonDown(object sender, MouseButtonEventArgs e)
		{
			this.StartDoubleClickTime();
			if(clickCount == 0)
			{
				row = sender as GridViewRow;
			}

			if (this.clickCount > 0 && row.Equals(sender as GridViewRow))
				this.OnDoubleClick();
			
			this.clickCount++;
		}

		private void StartDoubleClickTime()
		{
			if (this.doubleClickTimer != null)
			{
				this.doubleClickTimer.Stop();
			}

			this.doubleClickTimer = new DispatcherTimer();
			this.doubleClickTimer.Interval = TimeSpan.FromMilliseconds(300);
			this.doubleClickTimer.Tick += new EventHandler(doubleClickTimer_Tick);
			this.doubleClickTimer.Start();
		}

		void doubleClickTimer_Tick(object sender, EventArgs e)
		{
			this.doubleClickTimer.Stop();
			this.clickCount = 0;
		}

		//Here you may implement the logic you want once a row is double-clicked.
		private void OnDoubleClick()
		{
			MessageBox.Show("The row has been activated");			
		}
	}
}
